import { profileCardsItems } from '@/types/blog';
import Image from 'next/image';
import React from 'react';
import Markdown from 'react-markdown';


interface Banner {
  img: string;
  width: number;
  height: number;
}

interface BlogPageProps {
  id: number;
  title: string;
  authorDetails: profileCardsItems;
  categories: string[];
  banner: Banner;
  readingTime: number;
  content: string;
  category: string;
}

const BlogPage: React.FC<BlogPageProps> = ({ title, authorDetails, category, readingTime, banner, content, categories }) => {
  const date = new Date(authorDetails.date);
  return (
    <div className="max-w-[1200px] mx-auto mt-10 px-4">
      <div className="lg:px-20">
        <h3 className="text-[1.4em] sm:text-4xl md:text-5xl font-libre font-bold sm:font-semibold dark:text-white">{title}</h3>
        <div className="my-5 text-textColor flex gap-4 flex-wrap items-center text-sm sm:text-md">
          {authorDetails && (
            <>
              <p className="font-semibold capitalize dark:text-white">
                posted on <span className="font-bold text-gray-400 dark:text-white">{date.toLocaleString('default', { month: 'short' })} {date.getDate()}, {date.getFullYear()}</span>
              </p>
              <p className="font-semibold capitalize dark:text-white">
                by <span className="font-bold text-gray-400 dark:text-white">{authorDetails.author}</span>
              </p>
            </>
          )}
          {category && (
            <p className="font-semibold capitalize dark:text-white">
              Published In <span className="font-bold text-gray-400 dark:text-white">{category}</span>
            </p>
          )}
          {readingTime && (
            <p className="font-bold text-gray-300 dark:text-white">
              {readingTime} min read
            </p>
          )}
        </div>
      </div>
      {banner && (
        <Image src={banner.img} alt="banner" width={banner.width} height={banner.height} className="rounded-xl w-full object-cover h-[250px] sm:h-[350px]" />
      )}
      <div className="w-full mt-12 dark:bg-[#131617] rounded-md px-4 py-6 sm:px-8">
        <div className="prose-xl prose-h2:font-libre prose-h2:font-bold prose-h2:text-2xl sm:prose-h2:text-[1.4em] prose-p:text-[14px] prose-p:leading-6 sm:prose-p:text-lg dark:text-white rounded-lg prose-li:list-decimal dark:prose-p:text-gray-400 leading-snug prose-blockquote:px-[30px] prose-h4:m-0 prose-blockquote:py-[15px] prose-blockquote:border-l-2 prose-blockquote:border-primary prose-h4:font-libre prose-h4:text-[1.5em] dark:prose-li:text-gray-400 prose-li:text-[17px]">
          <Markdown>
            {content || ''}
          </Markdown>
        </div>
        <ul className="dark:text-gray-400 prose-li:list-none mt-10 flex gap-3 items-center flex-wrap">
          <li className="text-lg">Tags:</li>
          {categories && categories.map((item, index) => (
            <li key={index} className="px-4 hover:bg-primary hover:text-white dark:hover:bg-primary cursor-pointer text-lg py-1 list-none dark:bg-[#2a2a2a] bg-secondary text-textColor dark:text-white w-max rounded-3xl">
              {item}
            </li>
          ))}
        </ul>
      </div>
    </div>
  );
}

export default BlogPage;
