import type { Meta, StoryObj } from '@storybook/react';
import cn from 'classnames';
import Button from './Button';
import React from 'react';

const meta: Meta<typeof Button> = {
  title: 'Basic/Button',
  component: Button,
  tags: ['autodocs']
};

export default meta;

type Story = StoryObj<typeof meta>;


const Template = () => {
  return (
    <div className={cn('w-full min-h-full px-2 ',
      'dark:bg-black dark:*:text-white')}>
      <h6 className="mb-2 font-semibold">Size</h6>
      <div className="flex gap-5 mb-4 flex-wrap items-center">
        <Button   size="sm">
          Small button
        </Button>
        <Button  size='md'>Medium button</Button>
        <Button   href="/" size="sm">
          Small Anchor
        </Button>
        <Button   href="/" size='md'>
          Medium Anchor
        </Button>

      </div>
      <h6 className="mb-2 font-semibold">Loading</h6>
      <div className="flex gap-5 mb-4 flex-wrap items-center">
        <Button   size="sm" loading>
          Small button
        </Button>
        <Button   size='md' loading>
          Medium button
        </Button>
        <Button   href="/" size="sm" loading>
          Small Anchor
        </Button>
        <Button   size="md" href="/" loading>
          Medium Anchor
        </Button>

      </div>
      <h6 className="mb-2 font-semibold">Disabled</h6>
      <div className="flex gap-5 mb-4 flex-wrap items-center">
        <Button   size="sm" disabled>
          Small button
        </Button>
        <Button   size='md' disabled>
          Medium button
        </Button>

      </div>
      <h6 className="mb-2 font-semibold">Disabled & Loading</h6>
      <div className="flex gap-5 mb-4 flex-wrap items-center">
        <Button   size="sm" loading disabled>
          Small button
        </Button>
        <Button   size='md' loading disabled>
          Medium button 
        </Button>

      </div>
      <h6 className="mb-2 font-semibold">Multiline</h6>
      <div className="flex gap-5 mb-4 flex-wrap items-center">
        <Button   size="sm">
          Lorem ipsum dolor sit <br /> amet consectetur adipisicing elit. <br />{' '}
          Quas exercitationem unde voluptate iure dolore laudantium.
        </Button>
        <Button  size='md'>
          Lorem ipsum dolor sit amet consectetur adipisicing elit. <br /> Quas
          exercitationem unde voluptate iure dolore laudantium.
        </Button>
      </div>
      <br />
      <div className="flex gap-5 mb-4 flex-wrap items-center">
        <Button   size="sm" loading>
          Lorem ipsum dolor sit <br /> amet consectetur adipisicing elit. <br />{' '}
          Quas exercitationem unde voluptate iure dolore laudantium.
        </Button>
        <Button  size='md' loading>
          Lorem ipsum dolor sit amet consectetur adipisicing elit. <br /> Quas
          exercitationem unde voluptate iure dolore laudantium.
        </Button>
      </div>
      <h6 className="mb-2 font-semibold">Block</h6>
      <div className="flex flex-col gap-5">
        <Button   size="sm" block>
          Small button
        </Button>
        <Button   size='md' block>
          Medium button
        </Button>
        <Button   size="sm" block loading>
          Small button
        </Button>
        <Button  size="md" block loading>
          Medium button
        </Button>
        <Button   size="sm" block loading disabled>
          Small button
        </Button>
        <Button  size='md' block loading disabled>
          Medium button
        </Button>
      </div>
    </div>
  );
};

export const Button_: Story = {
  render: () => <Template />
};

