import cn from 'classnames';
import Link from 'next/link';

interface ButtonProps extends React.HTMLAttributes<HTMLElement> {
  children: React.ReactNode;
    size: 'sm' | 'md' | 'icon';
  disabled?: boolean;
  href?: string;
  loading?: boolean;
  block?: boolean
  isPrimary?: boolean;
}

export default function Button({ children, size, disabled, className, loading, href,isPrimary, block, ...props }: ButtonProps) {
   const classes = cn('inline-flex items-center justify-center gap-1 font-sans font-[700] text-textColor   leading-2 rounded-xl border-[1px] h-auto dark  dark:border-none ', {
        'px-4 py-2 text-[18px]': size === 'sm',
        'px-6 py-2 text-[22px]': size === 'md',
        'px-4 py-2 text-[15px]':size ==='icon',
        'bg-secondary hover:bg-none hover:dark:bg-none opacity-50': disabled,
     'hover:bg-primary hover:text-white ease-in duration-100': !disabled,
     'w-full': block,
     'bg-white dark:bg-[#131617] dark:text-white':!isPrimary,
     'bg-primary text-white': isPrimary
    },className)

  return typeof href === 'string' ? (
    <Link href={href} className={classes} {...props}>
      {children}
      {loading && <Loader />}
    </Link>
  ) : (
    <button disabled={disabled} className={classes} {...props}>
      {children}
      {loading && <Loader />}
    </button>
  );
}

function Loader() {
  return (
    <span className="rounded-full h-5 w-5 border-2 border-b-transparent border-current dark:bg-[] animate-spin ms-2" />
  );
}
