'use client';
import Image from 'next/image';
import React, { useState } from 'react';
import cn from 'classnames';
import SearchBar from '@/components/Top-Level/Searchbar/SearchBar';
import Newspaper from '@/public/Icons/icons-newspaper.svg'
import {Moon,Sun} from "@/utils/icons";
import menu from "@/public/Icons/icons-menu.svg"
import Link from 'next/link';
interface HeaderProps {
    onSearch: (search:string) => void;
    onChangeTheme: () => void;
    isVisible?: boolean;
}
const Navigation: React.FC<HeaderProps> = ({ onSearch,onChangeTheme,isVisible }) => {
    const [isOPen, setisOPen] = useState(false);
    return (
         <div className="sticky top-0 dark:bg-[#131617] bg-white  dark:text-white shadow-md p-4 z-50">
            <div className="w-full justify-between flex items-center max-w-[1100px] mx-auto">
                <Link className="flex gap-2 items-center py-[10px]" href="/">
                    <Image src={Newspaper} height={40} width={40} alt="Newspaper" />
                    <h1 className="font-semibold text-2xl">NewsBlog</h1>
                </Link>
                {
                    isVisible &&
                    <div className={"hidden md:block min-w-[400px]"}>
                    
                    <SearchBar placeholder="Discover news, articles, and more" className="font-semibold" onSearch={onSearch} />
                </div>
                }
                <div className='ml-auto mr-2 md:m-0'>
                    <Sun handleClick={onChangeTheme} />
                    <Moon handleClick={onChangeTheme} />
                </div>
                {
                    isVisible &&
                    <div className="block md:hidden w-[40px] h-[40px] rounded-md p-2 bg-primary cursor-pointer *:mr-2" onClick={() => setisOPen(!isOPen)}>

                    <Image src={menu} alt="Menu" className="w-full h-full" width={100} height={100} />
                </div>
                }
            </div>
            <div className={cn('h-0 overflow-hidden md:hidden transition-all duration-100 ease-in-out container bg-white dark:bg-[#131617] ', {
                'h-auto py-2 min-w-full mt-2': isOPen
            })}>
                
                    <SearchBar placeholder="Discover news, articles, and more" className="font-semibold" onSearch={onSearch} />
               
            </div>
        </div>
    );
}
 
export default Navigation;